==> idoit-1.12-update.zip: updates/versions/v1.12/files/src/classes/modules/multiedit/lang/de.inc.php <==
<?php

return [
    'LC__MODULE__MULTIEDIT'                                              => 'Listeneditierung',
    'LC__MODULE__MULTIEDIT__CREATE_NEW_VALUE'                            => 'Neuen Eintrag hinzufügen',
    'LC__MODULE__MULTIEDIT__OBJECTS_AND_CATEGORY'                        => 'Objekt(e) und Kategorie',
    'LC__MODULE__MULTIEDIT__OBJECT_HAS_NO_DATA_IN_CATEGORY'              => 'Dieses Objekt verfügt bisher über keine Daten in dieser Kategorie.',
    'LC__MODULE__MULTIEDIT__SELECTED_CATEGORY_IS_NOT_ASSIGNED_TO_OBJECT' => 'Ausgewählte Kategorie ist diesem Objekt nicht zugewiesen.',
    'LC__MODULE__MULTIEDIT__NO_RIGHTS'                                   => 'Sie verfügen nicht über die Berechtigung, die gewählte Kategorie des Objekts zu bearbeiten.',
    'LC__MODULE__MULTIEDIT__IT_IS_NOT_POSSIBLE_TO_CHANGE_ALL'            => 'Dieses Feld hat eine Abhängigkeit zu einer anderen Kategorie.',
    'LC__MODULE__MULTIEDIT__REGISTERED_DISABLED_ROWS'                    => 'Ausgeblendete Datensätze',
    'LC__MODULE__MULTIEDIT__ADD_VALUES'                                  => 'Neuen Wert hinzufügen',
    'LC__MODULE__MULTIEDIT__ADD_VALUES__ADD'                             => 'Hinzufügen',
    'LC__MODULE__MULTIEDIT__OPEN_OBJECTS_IN_MULTIEDIT'                   => 'Objekte in der Listenedierung editieren',
    'LC__MODULE__MULTIEDIT_CATEGORY'                                     => 'Listeneditierung',
    'LC__MODULE__MULTIEDIT__AUTH_ERROR'                                  => 'Sie verfügen nicht über die Berechtigung für die Listeneditierung.',
    'LC__MODULE__MULTIEDIT__CATEGORY_IS_NOT_AVAILABLE_FOR_LISTEDIT'      => 'Die Kategorie "%s" ist für die Listenedierung nicht verfügbar.',
    'LC__MODULE__MULTIEDIT__MULTIVALUE_INFO_TEXT'                        => 'Sie haben eine Multi-Value-Kategorie zur Bearbeitung ausgewählt. Bitte beachten Sie, dass nur bestehende Inhalte bearbeitet werden können. Sollte ein Objekt bisher über keinen Eintrag verfügen, ergänzen Sie diesen bitte zuerst über die Schaltfläche “Neue Zeile hinzufügen” für das entsprechende Objekt oder über die Schaltfläche “Neuen Eintrag hinzufügen” in der Zeile des gewünschten Objekts . Anschließend können Sie die Informationen dieses Eintrag in der Listeneditierung bearbeiten. Objekte, die bisher über keinen Eintrag in der Listeneditierung verfügen, tauchen erst in dieser Liste auf, sobald ein Eintrag wie oben beschrieben hinzugefügt wurde.',
    'LC__MODULE__MULTIEDIT__HIDE_SYSID_AND_OBJECT_ID'                    => 'SYSID und Objekt-ID ausblenden',
    'LC__MODULE__MULTIEDIT__SHOW_SYSID_AND_OBJECT_ID'                    => 'SYSID und Objekt-ID anzeigen',
    'LC__MODULE__MULTIEDIT__SHOW_SYSID'                                  => 'SYSID anzeigen',
    'LC__MODULE__MULTIEDIT__SHOW_OBJECT_ID'                              => 'Objekt-ID anzeigen',
    'LC__AUTH__MULTIEDIT_EXCEPTION__MISSING_RIGHT_FOR_MULTIEDIT'         => 'Sie verfügen über unzureichende Rechte, um die Listeneditierung zu öffnen.',
];

==> idoit-1.13-update.zip: updates/versions/v1.13/files/src/classes/modules/multiedit/lang/de.inc.php <==
<?php

return [
    'LC__MODULE__MULTIEDIT'                                              => 'Listeneditierung',
    'LC__MODULE__MULTIEDIT__CREATE_NEW_VALUE'                            => 'Neuen Eintrag hinzufügen',
    'LC__MODULE__MULTIEDIT__OBJECTS_AND_CATEGORY'                        => 'Objekt(e) und Kategorie',
    'LC__MODULE__MULTIEDIT__OBJECT_HAS_NO_DATA_IN_CATEGORY'              => 'Dieses Objekt verfügt bisher über keine Daten in dieser Kategorie.',
    'LC__MODULE__MULTIEDIT__SELECTED_CATEGORY_IS_NOT_ASSIGNED_TO_OBJECT' => 'Ausgewählte Kategorie ist diesem Objekt nicht zugewiesen.',
    'LC__MODULE__MULTIEDIT__NO_RIGHTS'                                   => 'Sie verfügen nicht über die Berechtigung, die gewählte Kategorie des Objekts zu bearbeiten.',
    'LC__MODULE__MULTIEDIT__IT_IS_NOT_POSSIBLE_TO_CHANGE_ALL'            => 'Dieses Feld hat eine Abhängigkeit zu einer anderen Kategorie.',
    'LC__MODULE__MULTIEDIT__REGISTERED_DISABLED_ROWS'                    => 'Ausgeblendete Datensätze',
    'LC__MODULE__MULTIEDIT__ADD_VALUES'                                  => 'Neuen Wert hinzufügen',
    'LC__MODULE__MULTIEDIT__ADD_VALUES__ADD'                             => 'Hinzufügen',
    'LC__MODULE__MULTIEDIT__OPEN_OBJECTS_IN_MULTIEDIT'                   => 'Objekte in der Listenedierung editieren',
    'LC__MODULE__MULTIEDIT_CATEGORY'                                     => 'Listeneditierung',
    'LC__MODULE__MULTIEDIT__AUTH_ERROR'                                  => 'Sie verfügen nicht über die Berechtigung für die Listeneditierung.',
    'LC__MODULE__MULTIEDIT__CATEGORY_IS_NOT_AVAILABLE_FOR_LISTEDIT'      => 'Die Kategorie "%s" ist für die Listenedierung nicht verfügbar.',
    'LC__MODULE__MULTIEDIT__MULTIVALUE_INFO_TEXT'                        => 'Sie haben eine Multi-Value-Kategorie zur Bearbeitung ausgewählt. Bitte beachten Sie, dass nur bestehende Inhalte bearbeitet werden können. Sollte ein Objekt bisher über keinen Eintrag verfügen, ergänzen Sie diesen bitte zuerst über die Schaltfläche “Neue Zeile hinzufügen” für das entsprechende Objekt oder über die Schaltfläche “Neuen Eintrag hinzufügen” in der Zeile des gewünschten Objekts . Anschließend können Sie die Informationen dieses Eintrag in der Listeneditierung bearbeiten. Objekte, die bisher über keinen Eintrag in der Listeneditierung verfügen, tauchen erst in dieser Liste auf, sobald ein Eintrag wie oben beschrieben hinzugefügt wurde.',
    'LC__MODULE__MULTIEDIT__HIDE_SYSID_AND_OBJECT_ID'                    => 'SYSID und Objekt-ID ausblenden',
    'LC__MODULE__MULTIEDIT__SHOW_SYSID_AND_OBJECT_ID'                    => 'SYSID und Objekt-ID anzeigen',
    'LC__MODULE__MULTIEDIT__SHOW_SYSID'                                  => 'SYSID anzeigen',
    'LC__MODULE__MULTIEDIT__SHOW_OBJECT_ID'                              => 'Objekt-ID anzeigen',
    'LC__MODULE__MULTIEDIT__SKIP_ATTRIBUTES_WITH_VALIDATION_ERROR'       => 'Attribute mit Validierungsfehlern wurden nicht übernommen.',
    'LC__MODULE__MULTIEDIT__SKIP_DATASETS_WITH_VALIDATION_ERROR'         => 'Datensätze mit Validierungsfehlern wurden nicht übernommen.',
    'LC__AUTH__MULTIEDIT_EXCEPTION__MISSING_RIGHT_FOR_MULTIEDIT'         => 'Sie verfügen über unzureichende Rechte, um die Listeneditierung zu öffnen.',
];
